@@ -18,8 +18,8 @@ import json
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.core.paginator import Paginator, EmptyPage
+from eggplant.validators.number import range_validator
 from eggplant.validators.string import is_positive_integer
-from eggplant.validators.iterator import len_validator
 from eggplant.views import exceptions
 from eggplant.views.api import APIView
 from eggplant.views.exceptions import ViewError
@@ -71,8 +71,8 @@ class ModelCollectionView(ModelViewBase):
 
     @validate_keys(
         (('page_size', 'limit'),
-          (is_positive_integer, len_validator(1, '>='),
-           len_validator(getattr(settings, MAX_PAGINATION_SIZE, eggplant_defaults.EGGPLANT_MAX_PAGINATION_SIZE), '<=')
+          (is_positive_integer, range_validator(1, '>='),
+           range_validator(getattr(settings, MAX_PAGINATION_SIZE, eggplant_defaults.EGGPLANT_MAX_PAGINATION_SIZE), '<=')
           )
          ),
         (('page_num', 'offset'), is_positive_integer)
@@ -102,7 +102,8 @@ class ModelCollectionView(ModelViewBase):
                     current_page_num,
                     paginator.page_range[0],
                     paginator.page_range[-1],
-                    )
+                    ),
+                    reason='WPNOutOfPage'
                 )
             queryset = target_page.object_list
 
@@ -145,7 +146,7 @@ class ModelCollectionView(ModelViewBase):
 
         result = {
             'data': collection,
-            'pagination': meta_info,
+            'meta': meta_info,
         }
         self.response.content = json.dumps(result)
 
